@@ -105,8 +105,8 @@ class PyScanner(MF):
         self.modules = {}; self.name = str(node)
         try: self.run_script(self.name)
         except: pass
-        imports = list(os.path.abspath(m.__file__) for m in self.modules.values() 
-            if self.path_filter(m.__file__))
+        imports = [m.__file__ for m in self.modules.values() if m.__file__ != None]
+        imports = list(os.path.abspath(m) for m in imports if self.path_filter(m))
         return imports
 
 def ToList(input):
